@@ -3,33 +3,21 @@ use warnings;
 use MRO::Compat 'c3';
 
 package WebService::Shippo::CustomsItem;
-use base (
-    'WebService::Shippo::Resource',
-    'WebService::Shippo::Creator',
-    'WebService::Shippo::Fetcher',
+use base qw(
+    WebService::Shippo::Resource
+    WebService::Shippo::Creator
+    WebService::Shippo::Fetcher
 );
 
 sub api_resource ()     { 'customs/items' }
+
 sub collection_class () { 'WebService::Shippo::CustomsItems' }
+
 sub item_class ()       { __PACKAGE__ }
 
-package    # Hide from PAUSE
-    WebService::Shippo::CustomsItems;
-use base (
-    'WebService::Shippo::Collection',
-    'WebService::Shippo::Creator',
-    'WebService::Shippo::Fetcher',
-);
-
-sub item_class ()       { 'WebService::Shippo::CustomsItem' }
-sub collection_class () { __PACKAGE__ }
-
 BEGIN {
     no warnings 'once';
-    # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
-    # namespace is just cruel; allow the use of "Shippo", too.
-    *Shippo::CustomsItem::  = *WebService::Shippo::CustomsItem::;
-    *Shippo::CustomsItems:: = *WebService::Shippo::CustomsItems::;
+    *Shippo::CustomsItem:: = *WebService::Shippo::CustomsItem::;
 }
 
 1;
@@ -40,11 +28,11 @@ BEGIN {
 
 =head1 NAME
 
-WebService::Shippo::CustomsItem - Shippo Customs Item class
+WebService::Shippo::CustomsItem - Customs Item class
 
 =head1 VERSION
 
-version 0.0.16
+version 0.0.17
 
 =head1 DESCRIPTION
 
