@@ -3,33 +3,21 @@ use warnings;
 use MRO::Compat 'c3';
 
 package WebService::Shippo::Manifest;
-use base (
-    'WebService::Shippo::Resource',
-    'WebService::Shippo::Creator',
-    'WebService::Shippo::Fetcher',
+use base qw(
+    WebService::Shippo::Resource
+    WebService::Shippo::Creator
+    WebService::Shippo::Fetcher
 );
 
-sub api_resource ()     { 'manifests' }
+sub api_resource () { 'manifests' }
+
 sub collection_class () { 'WebService::Shippo::Manifests' }
-sub item_class ()       { __PACKAGE__ }
 
-package    # Hide from PAUSE
-    WebService::Shippo::Manifests;
-use base (
-    'WebService::Shippo::Collection',
-    'WebService::Shippo::Creator',
-    'WebService::Shippo::Fetcher',
-);
-
-sub item_class ()       { 'WebService::Shippo::Manifest' }
-sub collection_class () { __PACKAGE__ }
+sub item_class () { __PACKAGE__ }
 
 BEGIN {
     no warnings 'once';
-    # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
-    # namespace is just cruel; allow the use of "Shippo", too.
-    *Shippo::Manifest::  = *WebService::Shippo::Manifest::;
-    *Shippo::Manifests:: = *WebService::Shippo::Manifests::;
+    *Shippo::Manifest:: = *WebService::Shippo::Manifest::;
 }
 
 1;
@@ -40,11 +28,11 @@ BEGIN {
 
 =head1 NAME
 
-WebService::Shippo::CarrierAccount - Shippo Manifest class
+WebService::Shippo::CarrierAccount - Manifest class
 
 =head1 VERSION
 
-version 0.0.16
+version 0.0.17
 
 =head1 DESCRIPTION
 
