@@ -3,33 +3,21 @@ use warnings;
 use MRO::Compat 'c3';
 
 package WebService::Shippo::Parcel;
-use base (
-    'WebService::Shippo::Resource',
-    'WebService::Shippo::Creator',
-    'WebService::Shippo::Fetcher',
+use base qw(
+    WebService::Shippo::Resource
+    WebService::Shippo::Creator
+    WebService::Shippo::Fetcher
 );
 
 sub api_resource ()     { 'parcels' }
+
 sub collection_class () { 'WebService::Shippo::Parcels' }
+
 sub item_class ()       { __PACKAGE__ }
 
-package    # Hide from PAUSE
-    WebService::Shippo::Parcels;
-use base (
-    'WebService::Shippo::Collection',
-    'WebService::Shippo::Creator',
-    'WebService::Shippo::Fetcher',
-);
-
-sub item_class ()       { 'WebService::Shippo::Parcel' }
-sub collection_class () { __PACKAGE__ }
-
 BEGIN {
     no warnings 'once';
-    # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
-    # namespace is just cruel; allow the use of "Shippo", too.
-    *Shippo::Parcel::  = *WebService::Shippo::Parcel::;
-    *Shippo::Parcels:: = *WebService::Shippo::Parcels::;
+    *Shippo::Parcel:: = *WebService::Shippo::Parcel::;
 }
 
 1;
@@ -40,11 +28,11 @@ BEGIN {
 
 =head1 NAME
 
-WebService::Shippo::Parcel - Shippo Parcel class.
+WebService::Shippo::Parcel - Parcel class
 
 =head1 VERSION
 
-version 0.0.16
+version 0.0.17
 
 =head1 DESCRIPTION
 
