@@ -4,14 +4,16 @@ use MRO::Compat 'c3';
 
 package WebService::Shippo::Rate;
 require WebService::Shippo::Shipment;
-use base (
-    'WebService::Shippo::Resource',
-    'WebService::Shippo::Fetcher',
+use base qw(
+    WebService::Shippo::Resource
+    WebService::Shippo::Fetcher
 );
 
-sub api_resource ()     { 'rates' }
+sub api_resource () { 'rates' }
+
 sub collection_class () { 'WebService::Shippo::Rates' }
-sub item_class ()       { __PACKAGE__ }
+
+sub item_class () { __PACKAGE__ }
 
 sub get_shipping_rates
 {
@@ -19,22 +21,9 @@ sub get_shipping_rates
     WebService::Shippo::Shipment->get_shipping_rates( @params );
 }
 
-package    # Hide from PAUSE
-    WebService::Shippo::Rates;
-use base (
-    'WebService::Shippo::Collection',
-    'WebService::Shippo::Fetcher',
-);
-
-sub item_class ()       { 'WebService::Shippo::Rate' }
-sub collection_class () { __PACKAGE__ }
-
 BEGIN {
     no warnings 'once';
-    # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
-    # namespace is just cruel; allow the use of "Shippo", too.
-    *Shippo::Rate::  = *WebService::Shippo::Rate::;
-    *Shippo::Rates:: = *WebService::Shippo::Rates::;
+    *Shippo::Rate:: = *WebService::Shippo::Rate::;
 }
 
 1;
@@ -45,11 +34,11 @@ BEGIN {
 
 =head1 NAME
 
-WebService::Shippo::Rate - Shippo Rate class.
+WebService::Shippo::Rate - Rate class
 
 =head1 VERSION
 
-version 0.0.16
+version 0.0.17
 
 =head1 DESCRIPTION
 
