@@ -5,16 +5,18 @@ use MRO::Compat 'c3';
 package WebService::Shippo::Transaction;
 use Carp         ( 'confess' );
 use Scalar::Util ( 'blessed' );
-use base (
-    'WebService::Shippo::Resource',
-    'WebService::Shippo::Creator',
-    'WebService::Shippo::Fetcher',
-    'WebService::Shippo::Async',
+use base qw(
+    WebService::Shippo::Resource
+    WebService::Shippo::Creator
+    WebService::Shippo::Fetcher
+    WebService::Shippo::Async
 );
 
-sub api_resource ()     { 'transactions' }
+sub api_resource () { 'transactions' }
+
 sub collection_class () { 'WebService::Shippo::Transactions' }
-sub item_class ()       { __PACKAGE__ }
+
+sub item_class () { __PACKAGE__ }
 
 sub get_shipping_label
 {
@@ -32,23 +34,10 @@ sub get_shipping_label
         unless $params{async};
     return $transaction->label_url;
 }
-package    # Hide from PAUSE
-    WebService::Shippo::Transactions;
-use base (
-    'WebService::Shippo::Collection',
-    'WebService::Shippo::Creator',
-    'WebService::Shippo::Fetcher',
-);
-
-sub item_class ()       { 'WebService::Shippo::Transaction' }
-sub collection_class () { __PACKAGE__ }
 
 BEGIN {
     no warnings 'once';
-    # Forcing the dev to always use CPAN's perferred "WebService::Shippo"
-    # namespace is just cruel; allow the use of "Shippo", too.
-    *Shippo::Transaction::     = *WebService::Shippo::Transaction::;
-    *Shippo::TransactionList:: = *WebService::Shippo::TransactionList::;
+    *Shippo::Transaction:: = *WebService::Shippo::Transaction::;
 }
 
 1;
@@ -59,11 +48,11 @@ BEGIN {
 
 =head1 NAME
 
-WebService::Shippo::Transaction - Shippo Transaction class.
+WebService::Shippo::Transaction - Transaction class
 
 =head1 VERSION
 
-version 0.0.16
+version 0.0.17
 
 =head1 DESCRIPTION
 
